Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(96)

Unified Diff: ios/chrome/browser/ui/tools_menu/tools_popup_controller.h

Issue 2714813002: [iOS] Add Request Mobile Site cell to tools menu (Closed)
Patch Set: Fix unit test Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/tools_menu/tools_popup_controller.h
diff --git a/ios/chrome/browser/ui/tools_menu/tools_popup_controller.h b/ios/chrome/browser/ui/tools_menu/tools_popup_controller.h
index a5d820fb5f0b1e1a4efb051b9e43e90c2cd3ab2f..e91c6441edea9a383037ef83841e355b9b1efd60 100644
--- a/ios/chrome/browser/ui/tools_menu/tools_popup_controller.h
+++ b/ios/chrome/browser/ui/tools_menu/tools_popup_controller.h
@@ -12,7 +12,7 @@
// The a11y ID of the tools menu table view (used by integration tests).
extern NSString* const kToolsMenuTableViewId;
-@class ToolsMenuContext;
+@class ToolsMenuConfiguration;
// The view controller for the tools menu within the top toolbar.
// The menu is composed of two main view: a top view with icons and a bottom
@@ -21,9 +21,9 @@ extern NSString* const kToolsMenuTableViewId;
@property(nonatomic, assign) BOOL isCurrentPageBookmarked;
-// Initializes the popup with the given |context|, a set of information used to
-// determine the appearance of the menu and the entries displayed.
-- (instancetype)initWithContext:(ToolsMenuContext*)context;
+// Initializes the popup with the given |configuration|, a set of information
+// used to determine the appearance of the menu and the entries displayed.
+- (instancetype)initWithConfiguration:(ToolsMenuConfiguration*)configuration;
// Called when the current tab loading state changes.
- (void)setIsTabLoading:(BOOL)isTabLoading;
@@ -41,9 +41,6 @@ extern NSString* const kToolsMenuTableViewId;
// Informs tools popup menu whether the switch to reader mode is possible.
- (void)setCanUseReaderMode:(BOOL)enabled;
-// Informs tools popup menu whether "Request Desktop Site" can be enabled.
-- (void)setCanUseDesktopUserAgent:(BOOL)value;
-
@end
#endif // IOS_CHROME_BROWSER_UI_TOOLS_MENU_TOOLS_POPUP_CONTROLLER_H_

Powered by Google App Engine
This is Rietveld 408576698